@@ -1,3 +1,6 @@
+// Copyright (c) 2023 Yuki Kimoto
+// MIT License
+
 #include "spvm_native.h"
 
 #include <unistd.h>
@@ -11,8 +14,8 @@ int32_t SPVM__Sys__Signal__Constant__BUS_ADRALN(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = BUS_ADRALN;
   return 0;
 #else
-  env->die(env, stack, "BUS_ADRALN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "BUS_ADRALN is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -23,8 +26,8 @@ int32_t SPVM__Sys__Signal__Constant__BUS_ADRERR(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = BUS_ADRERR;
   return 0;
 #else
-  env->die(env, stack, "BUS_ADRERR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "BUS_ADRERR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -35,8 +38,8 @@ int32_t SPVM__Sys__Signal__Constant__BUS_MCEERR_AO(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = BUS_MCEERR_AO;
   return 0;
 #else
-  env->die(env, stack, "BUS_MCEERR_AO is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "BUS_MCEERR_AO is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -47,8 +50,8 @@ int32_t SPVM__Sys__Signal__Constant__BUS_MCEERR_AR(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = BUS_MCEERR_AR;
   return 0;
 #else
-  env->die(env, stack, "BUS_MCEERR_AR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "BUS_MCEERR_AR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -59,8 +62,8 @@ int32_t SPVM__Sys__Signal__Constant__BUS_MCERR_(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = BUS_MCERR_;
   return 0;
 #else
-  env->die(env, stack, "BUS_MCERR_ is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "BUS_MCERR_ is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -71,8 +74,8 @@ int32_t SPVM__Sys__Signal__Constant__BUS_OBJERR(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = BUS_OBJERR;
   return 0;
 #else
-  env->die(env, stack, "BUS_OBJERR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "BUS_OBJERR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -83,8 +86,8 @@ int32_t SPVM__Sys__Signal__Constant__CLD_CONTINUED(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = CLD_CONTINUED;
   return 0;
 #else
-  env->die(env, stack, "CLD_CONTINUED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "CLD_CONTINUED is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -95,8 +98,8 @@ int32_t SPVM__Sys__Signal__Constant__CLD_DUMPED(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = CLD_DUMPED;
   return 0;
 #else
-  env->die(env, stack, "CLD_DUMPED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "CLD_DUMPED is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -107,8 +110,8 @@ int32_t SPVM__Sys__Signal__Constant__CLD_EXITED(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = CLD_EXITED;
   return 0;
 #else
-  env->die(env, stack, "CLD_EXITED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "CLD_EXITED is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -119,8 +122,8 @@ int32_t SPVM__Sys__Signal__Constant__CLD_KILLED(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = CLD_KILLED;
   return 0;
 #else
-  env->die(env, stack, "CLD_KILLED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "CLD_KILLED is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -131,8 +134,8 @@ int32_t SPVM__Sys__Signal__Constant__CLD_STOPPED(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = CLD_STOPPED;
   return 0;
 #else
-  env->die(env, stack, "CLD_STOPPED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "CLD_STOPPED is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -143,8 +146,8 @@ int32_t SPVM__Sys__Signal__Constant__CLD_TRAPPED(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = CLD_TRAPPED;
   return 0;
 #else
-  env->die(env, stack, "CLD_TRAPPED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "CLD_TRAPPED is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -155,8 +158,8 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTDIV(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTDIV;
   return 0;
 #else
-  env->die(env, stack, "FPE_FLTDIV is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "FPE_FLTDIV is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -167,8 +170,8 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTINV(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTINV;
   return 0;
 #else
-  env->die(env, stack, "FPE_FLTINV is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "FPE_FLTINV is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -179,8 +182,8 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTOVF(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTOVF;
   return 0;
 #else
-  env->die(env, stack, "FPE_FLTOVF is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "FPE_FLTOVF is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -191,8 +194,8 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTRES(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTRES;
   return 0;
 #else
-  env->die(env, stack, "FPE_FLTRES is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "FPE_FLTRES is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -203,8 +206,8 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTSUB(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTSUB;
   return 0;
 #else
-  env->die(env, stack, "FPE_FLTSUB is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "FPE_FLTSUB is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -215,8 +218,8 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTUND(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTUND;
   return 0;
 #else
-  env->die(env, stack, "FPE_FLTUND is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "FPE_FLTUND is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -227,8 +230,8 @@ int32_t SPVM__Sys__Signal__Constant__FPE_INTDIV(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_INTDIV;
   return 0;
 #else
-  env->die(env, stack, "FPE_INTDIV is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "FPE_INTDIV is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -239,8 +242,8 @@ int32_t SPVM__Sys__Signal__Constant__FPE_INTOVF(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_INTOVF;
   return 0;
 #else
-  env->die(env, stack, "FPE_INTOVF is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "FPE_INTOVF is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -251,8 +254,8 @@ int32_t SPVM__Sys__Signal__Constant__FUTEX_WAIT(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FUTEX_WAIT;
   return 0;
 #else
-  env->die(env, stack, "FUTEX_WAIT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "FUTEX_WAIT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -263,8 +266,8 @@ int32_t SPVM__Sys__Signal__Constant__ILL_BADSTK(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_BADSTK;
   return 0;
 #else
-  env->die(env, stack, "ILL_BADSTK is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "ILL_BADSTK is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -275,8 +278,8 @@ int32_t SPVM__Sys__Signal__Constant__ILL_COPROC(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_COPROC;
   return 0;
 #else
-  env->die(env, stack, "ILL_COPROC is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "ILL_COPROC is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -287,8 +290,8 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLADR(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_ILLADR;
   return 0;
 #else
-  env->die(env, stack, "ILL_ILLADR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "ILL_ILLADR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -299,8 +302,8 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLOPC(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_ILLOPC;
   return 0;
 #else
-  env->die(env, stack, "ILL_ILLOPC is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "ILL_ILLOPC is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -311,8 +314,8 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLOPN(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_ILLOPN;
   return 0;
 #else
-  env->die(env, stack, "ILL_ILLOPN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "ILL_ILLOPN is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -323,8 +326,8 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLTRP(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_ILLTRP;
   return 0;
 #else
-  env->die(env, stack, "ILL_ILLTRP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "ILL_ILLTRP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -335,8 +338,8 @@ int32_t SPVM__Sys__Signal__Constant__ILL_PRVOPC(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_PRVOPC;
   return 0;
 #else
-  env->die(env, stack, "ILL_PRVOPC is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "ILL_PRVOPC is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -347,8 +350,8 @@ int32_t SPVM__Sys__Signal__Constant__ILL_PRVREG(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_PRVREG;
   return 0;
 #else
-  env->die(env, stack, "ILL_PRVREG is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "ILL_PRVREG is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -359,8 +362,8 @@ int32_t SPVM__Sys__Signal__Constant__POLL_ERR(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLL_ERR;
   return 0;
 #else
-  env->die(env, stack, "POLL_ERR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "POLL_ERR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -371,8 +374,8 @@ int32_t SPVM__Sys__Signal__Constant__POLL_HUP(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLL_HUP;
   return 0;
 #else
-  env->die(env, stack, "POLL_HUP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "POLL_HUP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -383,8 +386,8 @@ int32_t SPVM__Sys__Signal__Constant__POLL_IN(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = POLL_IN;
   return 0;
 #else
-  env->die(env, stack, "POLL_IN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "POLL_IN is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -395,8 +398,8 @@ int32_t SPVM__Sys__Signal__Constant__POLL_MSG(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLL_MSG;
   return 0;
 #else
-  env->die(env, stack, "POLL_MSG is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "POLL_MSG is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -407,8 +410,8 @@ int32_t SPVM__Sys__Signal__Constant__POLL_OUT(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLL_OUT;
   return 0;
 #else
-  env->die(env, stack, "POLL_OUT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "POLL_OUT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -419,8 +422,8 @@ int32_t SPVM__Sys__Signal__Constant__POLL_PRI(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLL_PRI;
   return 0;
 #else
-  env->die(env, stack, "POLL_PRI is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "POLL_PRI is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -431,8 +434,8 @@ int32_t SPVM__Sys__Signal__Constant__SI_SIGIO(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_SIGIO;
   return 0;
 #else
-  env->die(env, stack, "SI_SIGIO is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SI_SIGIO is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -443,8 +446,8 @@ int32_t SPVM__Sys__Signal__Constant__SI_ASYNCIO(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = SI_ASYNCIO;
   return 0;
 #else
-  env->die(env, stack, "SI_ASYNCIO is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SI_ASYNCIO is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -455,8 +458,8 @@ int32_t SPVM__Sys__Signal__Constant__SI_KERNEL(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_KERNEL;
   return 0;
 #else
-  env->die(env, stack, "SI_KERNEL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SI_KERNEL is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -467,8 +470,8 @@ int32_t SPVM__Sys__Signal__Constant__SI_MESGQ(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_MESGQ;
   return 0;
 #else
-  env->die(env, stack, "SI_MESGQ is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SI_MESGQ is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -479,8 +482,8 @@ int32_t SPVM__Sys__Signal__Constant__SI_QUEUE(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_QUEUE;
   return 0;
 #else
-  env->die(env, stack, "SI_QUEUE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SI_QUEUE is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -491,8 +494,8 @@ int32_t SPVM__Sys__Signal__Constant__SI_TIMER(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_TIMER;
   return 0;
 #else
-  env->die(env, stack, "SI_TIMER is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SI_TIMER is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -503,8 +506,8 @@ int32_t SPVM__Sys__Signal__Constant__SI_TKILL(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_TKILL;
   return 0;
 #else
-  env->die(env, stack, "SI_TKILL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SI_TKILL is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -515,8 +518,8 @@ int32_t SPVM__Sys__Signal__Constant__SI_USER(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SI_USER;
   return 0;
 #else
-  env->die(env, stack, "SI_USER is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SI_USER is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -527,8 +530,8 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_BRANCH(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = TRAP_BRANCH;
   return 0;
 #else
-  env->die(env, stack, "TRAP_BRANCH is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "TRAP_BRANCH is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -539,8 +542,8 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_BRKPT(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = TRAP_BRKPT;
   return 0;
 #else
-  env->die(env, stack, "TRAP_BRKPT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "TRAP_BRKPT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -551,8 +554,8 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_HWBKPT(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = TRAP_HWBKPT;
   return 0;
 #else
-  env->die(env, stack, "TRAP_HWBKPT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "TRAP_HWBKPT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -563,8 +566,8 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_TRACE(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = TRAP_TRACE;
   return 0;
 #else
-  env->die(env, stack, "TRAP_TRACE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "TRAP_TRACE is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -575,8 +578,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGABRT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGABRT;
   return 0;
 #else
-  env->die(env, stack, "SIGABRT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGABRT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -587,8 +590,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGALRM(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGALRM;
   return 0;
 #else
-  env->die(env, stack, "SIGALRM is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGALRM is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -599,8 +602,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGBUS(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGBUS;
   return 0;
 #else
-  env->die(env, stack, "SIGBUS is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGBUS is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -611,8 +614,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGCHLD(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGCHLD;
   return 0;
 #else
-  env->die(env, stack, "SIGCHLD is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGCHLD is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -623,8 +626,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGCONT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGCONT;
   return 0;
 #else
-  env->die(env, stack, "SIGCONT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGCONT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -635,8 +638,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGFPE(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGFPE;
   return 0;
 #else
-  env->die(env, stack, "SIGFPE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGFPE is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -647,8 +650,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGHUP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGHUP;
   return 0;
 #else
-  env->die(env, stack, "SIGHUP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGHUP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -659,8 +662,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGILL(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGILL;
   return 0;
 #else
-  env->die(env, stack, "SIGILL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGILL is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -671,8 +674,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGINT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGINT;
   return 0;
 #else
-  env->die(env, stack, "SIGINT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGINT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -683,8 +686,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGIO(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGIO;
   return 0;
 #else
-  env->die(env, stack, "SIGIO is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGIO is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -695,8 +698,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGKILL(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGKILL;
   return 0;
 #else
-  env->die(env, stack, "SIGKILL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGKILL is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -707,8 +710,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGPIPE(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGPIPE;
   return 0;
 #else
-  env->die(env, stack, "SIGPIPE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGPIPE is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -719,8 +722,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGPROF(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGPROF;
   return 0;
 #else
-  env->die(env, stack, "SIGPROF is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGPROF is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -731,8 +734,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGPWR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGPWR;
   return 0;
 #else
-  env->die(env, stack, "SIGPWR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGPWR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -743,8 +746,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGQUIT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGQUIT;
   return 0;
 #else
-  env->die(env, stack, "SIGQUIT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGQUIT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -755,8 +758,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGRTMAX(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SIGRTMAX;
   return 0;
 #else
-  env->die(env, stack, "SIGRTMAX is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGRTMAX is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -767,8 +770,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGRTMIN(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SIGRTMIN;
   return 0;
 #else
-  env->die(env, stack, "SIGRTMIN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGRTMIN is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -779,8 +782,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGSEGV(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGSEGV;
   return 0;
 #else
-  env->die(env, stack, "SIGSEGV is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGSEGV is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -791,8 +794,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGSTKFLT(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SIGSTKFLT;
   return 0;
 #else
-  env->die(env, stack, "SIGSTKFLT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGSTKFLT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -803,8 +806,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGSTOP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGSTOP;
   return 0;
 #else
-  env->die(env, stack, "SIGSTOP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGSTOP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -815,8 +818,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGSYS(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGSYS;
   return 0;
 #else
-  env->die(env, stack, "SIGSYS is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGSYS is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -827,8 +830,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGTERM(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGTERM;
   return 0;
 #else
-  env->die(env, stack, "SIGTERM is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGTERM is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -839,8 +842,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGTRAP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGTRAP;
   return 0;
 #else
-  env->die(env, stack, "SIGTRAP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGTRAP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -851,8 +854,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGTSTP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGTSTP;
   return 0;
 #else
-  env->die(env, stack, "SIGTSTP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGTSTP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -863,8 +866,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGTTIN(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGTTIN;
   return 0;
 #else
-  env->die(env, stack, "SIGTTIN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGTTIN is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -875,8 +878,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGTTOU(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGTTOU;
   return 0;
 #else
-  env->die(env, stack, "SIGTTOU is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGTTOU is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -887,8 +890,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGURG(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGURG;
   return 0;
 #else
-  env->die(env, stack, "SIGURG is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGURG is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -899,8 +902,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGUSR1(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGUSR1;
   return 0;
 #else
-  env->die(env, stack, "SIGUSR1 is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGUSR1 is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -911,8 +914,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGUSR2(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGUSR2;
   return 0;
 #else
-  env->die(env, stack, "SIGUSR2 is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGUSR2 is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -923,8 +926,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGVTALRM(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SIGVTALRM;
   return 0;
 #else
-  env->die(env, stack, "SIGVTALRM is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGVTALRM is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -935,8 +938,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGWINCH(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SIGWINCH;
   return 0;
 #else
-  env->die(env, stack, "SIGWINCH is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGWINCH is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -947,8 +950,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGXCPU(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGXCPU;
   return 0;
 #else
-  env->die(env, stack, "SIGXCPU is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGXCPU is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -959,8 +962,8 @@ int32_t SPVM__Sys__Signal__Constant__SIGXFSZ(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGXFSZ;
   return 0;
 #else
-  env->die(env, stack, "SIGXFSZ is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIGXFSZ is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -971,8 +974,8 @@ int32_t SPVM__Sys__Signal__Constant__SIG_DFL(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = (int32_t)(intptr_t)SIG_DFL;
   return 0;
 #else
-  env->die(env, stack, "SIG_DFL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIG_DFL is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -983,8 +986,8 @@ int32_t SPVM__Sys__Signal__Constant__SIG_ERR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = (int32_t)(intptr_t)SIG_ERR;
   return 0;
 #else
-  env->die(env, stack, "SIG_ERR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIG_ERR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -995,8 +998,8 @@ int32_t SPVM__Sys__Signal__Constant__SIG_IGN(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = (int32_t)(intptr_t)SIG_IGN;
   return 0;
 #else
-  env->die(env, stack, "SIG_IGN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  env->die(env, stack, "SIG_IGN is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
